@@ -20,6 +20,8 @@ pull_inc_earnings <- function(endyear, span, geography) {
   
   # 01 -- pull data and move to lists
   #----------------------------------------------
+  oldw <- getOption("warn")
+  options(warn= -1) # suppress warnings from library(acs) / ACS API
   gini <- acs::acs.fetch(endyear= endyear, span= span, geography= geography, 
                     table.number = "B19083", col.names= "pretty")
   inc_pc <- acs::acs.fetch(endyear= endyear, span= span, geography= geography, 
@@ -36,6 +38,7 @@ pull_inc_earnings <- function(endyear, span, geography) {
                           table.number = "B24011", col.names= "pretty")
 #   inc_by_int <- acs::acs.fetch(endyear= endyear, span= span, geography= geography, 
 #                           table.number = "B28004", col.names= "pretty")
+  options(warn= oldw) # turn warnings back on
   
   est <- list(gini= data.frame(gini@estimate),
               inc_pc= data.frame(inc_pc@estimate),
@@ -43,8 +46,8 @@ pull_inc_earnings <- function(endyear, span, geography) {
               vet_status= data.frame(vet_status@estimate),
               snap= data.frame(snap@estimate),
               mean_hrs_work= data.frame(mean_hrs_work@estimate),
-              med_earn= data.frame(med_earn@estimate[, c(1,4,5,7:9,11:14, 16:17,19,21:25,27,28,
-                                                         30:32,34:36)]))
+              med_earn= data.frame(t(med_earn@estimate[, c(1,4,5,7:9,11:14, 16:17,19,21:25,27,28,
+                                                         30:32,34:36)])))
   
   se <- list(gini= data.frame(gini@standard.error),
               inc_pc= data.frame(inc_pc@standard.error),
@@ -52,17 +55,8 @@ pull_inc_earnings <- function(endyear, span, geography) {
               vet_status= data.frame(vet_status@standard.error),
               snap= data.frame(snap@standard.error),
               mean_hrs_work= data.frame(mean_hrs_work@standard.error),
-              med_earn= data.frame(med_earn@standard.error[, c(1,4,5,7:9,11:14, 16:17,19,21:25,27,28,
-                                                         30:32,34:36)]))
-  
-  orig_colnames <- list(gini= data.frame(gini@estimate),
-              inc_pc= data.frame(inc_pc@estimate),
-              med_inc= data.frame(med_inc@estimate),
-              vet_status= data.frame(vet_status@estimate),
-              snap= data.frame(snap@estimate),
-              mean_hrs_work= data.frame(mean_hrs_work@estimate),
-              med_earn= data.frame(med_earn@estimate[c(1,4,5,7:9,11:14, 16:17,19,21:25,27,28,
-                                                         30:32,34:36)]))
+              med_earn= data.frame(t(med_earn@standard.error[, c(1,4,5,7:9,11:14, 16:17,19,21:25,27,28,
+                                                         30:32,34:36)])))
   
   geo <- gini@geography
   
