@@ -12,8 +12,8 @@ synth_data_pov <- function(agmeen_dat, pov_ge_vec, total_pop) {
   pov_pop <- pov_ge_vec[1]
   if (total_pop / pov_pop > 3 | (total_pop / pov_pop > 2 & pov_pop < 100)) {
     message("Data on poverty status is underreported. Marking all individauls as >= poverty line.")
-    dat <- mapply_synth(dat= agmeen_dat[[1]], prob_name= "p", attr_pct= 1.0, attr_name= "pov_status",
-                        level="at_above_pov_level")
+    dat <- add_synth_attr_level(dat= agmeen_dat[[1]], prob_name= "p", attr_name= "pov_status",
+                                attr= list(pct= 1.0, level="at_above_pov_level"))
     dat$pov_status <- factor(dat$pov_status, levels= c("below_pov_level", "at_above_pov_level"))
     return(list(dat, levels(dat$edu_attain)))
   }
@@ -63,10 +63,12 @@ pov_lapply <- function(l, levels, emp_marg) {
   comp <- emp_marg[which(names(emp_marg) %in% emp_levels)]
   comp <- c(comp, 1-comp)
   
+  st <- data.frame(pct= comp, levels= levels)
+  st <- base::split(st, 1:nrow(st))
+  
   dat <- replicate(length(emp_levels), l, simplify = FALSE)
-  dat <- do.call("rbind", mapply(mapply_synth, dat= dat, prob_name= "p", attr_pct= comp, 
-                                 attr_name= "pov_status", level= levels,
-                                 SIMPLIFY = FALSE))
+  dat <- do.call("rbind", mapply(add_synth_attr_level, dat= dat, prob_name= "p", attr= st,
+                                 attr_name= "pov_status", SIMPLIFY = FALSE))
   return(dat)
 }
 
@@ -90,12 +92,3 @@ marginalize_emp_status <- function(pov_vec, emp_levels) {
   }
   return(out)
 }
-
-# helper function for synth_data_pov. Internal to pov_lapply
-# pov_mapply <- function(dat, comp, levels) {
-#   dat <- data.frame(age= dat$age, gender= dat$gender, marital_status= dat$marital_status,
-#                     edu_attain= dat$edu_attain, emp_status= dat$emp_status, 
-#                     nativity= dat$nativity,
-#                     pov_status= levels, p= dat$p * comp)
-#   return(dat)
-# }
\ No newline at end of file
